

setwd("E:\\ARTICULO5_Europe\\Data\\Data\\Graficos_final\\Single_regression\\After_ revision")


library(dplyr)
library(ggplot2)



####################################
############# Figure 1 #############
####################################


## Data

COUNTRIES <- read.csv(file = 'Figure1.csv', sep = ',')

COUNTRIES$Country<- factor(COUNTRIES$Country, levels = c("Slovenia (E)",
                                                         "Greece (S)",
                                                         "Hungary (E)",
                                                         "Belgium (W)",
                                                         "Czech Republic (E)",
                                                         "Sweden (N)",
                                                         "Spain (S)",
                                                         "United Kingdom (W)",
                                                         "Switzerland (W)",
                                                         "EU-12",
                                                         "Italy (S)",
                                                         "Germany (W)",
                                                         "Portugal (S)"))

COUNTRIES$Education <- recode(COUNTRIES$Education,
                            "Low"="Less than secondary",
                            "Medium"="Secondary",
                            "High"="Tertiary")

COUNTRIES$Education <- factor(COUNTRIES$Education, levels = c("Less than secondary", "Secondary", "Tertiary"))


## Plot

bmp(file='Figure1.bmp', width = 6, height = 4.3, units = 'in', res = 300)

ggplot(data = COUNTRIES, aes(x = Country, y = OR, ymin = min, ymax = max, colour = Education)) +
  
  geom_point(position = position_dodge(width = 0.6), size=1.7) +
  
  geom_errorbar(position = position_dodge(width = 0.6), width = 0, size=0.4) +
  
  scale_colour_manual(values=c("#F89078", "#C0369D", "#4B2991"))+
  
  scale_y_continuous(limits=c(0,5), breaks=seq(0,5,1))+
  
  labs(x=NULL,y = "Odds ratios") +
  
  geom_hline(yintercept = 1, size=0.5, colour ="grey15", linetype="dashed")+
  
  annotate("rect", xmin =1.5 , xmax = 2.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =3.5 , xmax = 4.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =5.5 , xmax = 6.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =7.5 , xmax = 8.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =9.5 , xmax = 10.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =11.5 , xmax = 12.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  
  theme_bw()+
  
  theme(text = element_text(size = 10),
        strip.background = element_rect(size =0.6),
        
        panel.border = element_rect(size=0.6),
        
        axis.title.y = element_text(vjust=2.5,size=8.5),
        
        axis.text.x = element_text(size = 8.5, angle = 45, hjust = 1),
        axis.text.y = element_text(size = 8.5),
        
        axis.ticks.x = element_line(size = 0.6),
        axis.ticks.y = element_line(size = 0.6),
        
        panel.grid.major.y=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        panel.grid.minor.y=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        panel.grid.major.x=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        
        legend.title = element_blank(),
        legend.text = element_text(size =8.5),
        legend.position="bottom",
        legend.direction = "horizontal")

dev.off()



####################################
############# Figure 2 #############
####################################


## Data

COUNTRIES_B <- read.csv(file = 'Figure2.csv', sep = ',')


COUNTRIES_B$Type <- factor(COUNTRIES_B$Type, levels = c("Native-born with less than tertiary education",
                                                        "Native-born with tertiary education",
                                                        "Foreign-born with less than tertiary education",
                                                        "Foreign-born with tertiary education"))

COUNTRIES_B$Country <- recode(COUNTRIES_B$Country,
                              "Greece"="Greece (S)",
                              "Slovenia"="Slovenia (E)",
                              "Hungary"="Hungary (E)",
                              "Belgium"="Belgium (W)",
                              "Czech Republic"="Czech Republic (E)",
                              "United Kingdom"="United Kingdom (W)",
                              "Spain"="Spain (S)",
                              "Sweden"="Sweden (N)",
                              "Switzerland"="Switzerland (W)",
                              "EU-12"="EU-12",
                              "Germany"="Germany (W)",
                              "Italy"="Italy (S)",
                              "Portugal"="Portugal (S)")

COUNTRIES_B$Country<- factor(COUNTRIES_B$Country, levels = c("Hungary (E)",
                                                             "Greece (S)",
                                                             "Slovenia (E)",
                                                             "Sweden (N)",
                                                             "Switzerland (W)",
                                                             "Italy (S)",
                                                             "Germany (W)",
                                                             "Belgium (W)",
                                                             "Spain (S)",
                                                             "United Kingdom (W)",
                                                             "EU-12",
                                                             "Czech Republic (E)",
                                                             "Portugal (S)"))


## Plot

bmp(file="Figure2.bmp", width = 6, height = 4.2, units = 'in', res = 300)

ggplot(data = COUNTRIES_B, aes(x = Country, y = OR, ymin = min, ymax = max, colour = Type)) +
  
  geom_point(aes(colour=Type, shape = Type), position = position_dodge(width = 0.65), size=1.6) +
  
  geom_errorbar(aes(colour=Type), position = position_dodge(width = 0.65), width = 0, size=0.4) +
  
  scale_colour_manual(values = c("#F89078", "#4B2991", "#F89078", "#4B2991")) +
  
  scale_shape_manual(values = c(19, 19, 15, 15)) +
  
  scale_y_continuous(limits=c(0,9), breaks=seq(0,9,1))+
  
  guides(colour=guide_legend(nrow=2,byrow=TRUE))+
  
  labs(x=NULL,y = "Odds ratios") +
  
  geom_hline(yintercept = 1, size=0.5, colour ="grey15", linetype="dashed")+
  
  annotate("rect", xmin =1.5 , xmax = 2.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =3.5 , xmax = 4.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =5.5 , xmax = 6.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =7.5 , xmax = 8.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =9.5 , xmax = 10.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =11.5 , xmax = 12.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  
  theme_bw()+
  
  theme(text = element_text(size = 10.5),
        strip.background = element_rect(size =0.6),
        
        panel.border = element_rect(size=0.6),
        
        axis.title.y = element_text(vjust=2.5,size=8.3),
        
        axis.text.x = element_text(size = 8.3, angle = 45, hjust = 1),
        axis.text.y = element_text(size = 8.3),
        
        axis.ticks.x = element_line(size = 0.6),
        axis.ticks.y = element_line(size = 0.6),
        
        panel.grid.major.y=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        panel.grid.minor.y=element_blank(),
        panel.grid.major.x=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        
        legend.title = element_blank(),
        legend.text = element_text(size =8.5),
        legend.position="bottom",
        legend.key.size = unit(0.35, "cm"),
        legend.direction = "horizontal")

dev.off()



####################################
############# Figure 3 #############
####################################


## Data

COUNTRIES_B2 <- read.csv(file = 'Figure3.csv', sep = ',')


COUNTRIES_B2$Type <- factor(COUNTRIES_B2$Type, levels = c("Native-born with less than tertiary education",
                                                        "Native-born with tertiary education",
                                                        "EU-born with less than tertiary education",
                                                        "EU-born with tertiary education",
                                                        "Non-EU-born with less than tertiary education",
                                                        "Non-EU-born with tertiary education"))

COUNTRIES_B2$Type <- recode (COUNTRIES_B2$Type,
                            "Native-born with less than tertiary education"="Native-born with less than tertiary education",
                            "Native-born with tertiary education"="Native-born with tertiary education",
                            "EU-born with less than tertiary education"="EU+EFTA-born with less than tertiary education",
                            "EU-born with tertiary education"="EU+EFTA-born with tertiary education",
                            "Non-EU-born with less than tertiary education"="Non-EU+EFTA-born with less than tertiary education",
                            "Non-EU-born with tertiary education"="Non-EU+EFTA-born with tertiary education")

COUNTRIES_B2$Country <- recode(COUNTRIES_B2$Country,
                              "Greece"="Greece (S)",
                              "Hungary"="Hungary (E)",
                              "Belgium"="Belgium (W)",
                              "United Kingdom"="United Kingdom (W)",
                              "Spain"="Spain (S)",
                              "Sweden"="Sweden (N)",
                              "Switzerland"="Switzerland (W)",
                              "EU-12"="EU-12",
                              "Germany"="Germany (W)",
                              "Italy"="Italy (S)",
                              "Portugal"="Portugal (S)")

COUNTRIES_B2$Country<- factor(COUNTRIES_B2$Country, levels = c("Hungary (E)",
                                                             "Greece (S)",
                                                             "Sweden (N)",
                                                             "Switzerland (W)",
                                                             "Italy (S)",
                                                             "Germany (W)",
                                                             "Belgium (W)",
                                                             "United Kingdom (W)",
                                                             "Spain (S)",
                                                             "EU-12",
                                                             "Portugal (S)"))


## Plot

bmp(file="Figure3.bmp", width = 6.2, height = 4.7, units = 'in', res = 300)

ggplot(data = COUNTRIES_B2, aes(x = Country, y = OR, ymin = min, ymax = max, colour = Type)) +
  
  geom_point(aes(colour=Type, shape = Type), position = position_dodge(width = 0.8), size=1.4) +
  
  geom_errorbar(aes(colour=Type), position = position_dodge(width = 0.8), width = 0, size=0.35) +
  
  scale_colour_manual(values = c("#F89078", "#4B2991", "#F89078", "#4B2991", "#F89078", "#4B2991")) +
  
  scale_shape_manual(values = c(19, 19, 15, 15, 17, 17)) +
  
  scale_y_continuous(limits=c(0,8), breaks=seq(0,8,1))+
  
  guides(colour=guide_legend(nrow=3,byrow=TRUE))+
  
  labs(x=NULL,y = "Odds ratios") +
  
  geom_hline(yintercept = 1, size=0.5, colour ="grey15", linetype="dashed")+
  
  annotate("rect", xmin =1.5 , xmax = 2.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =3.5 , xmax = 4.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =5.5 , xmax = 6.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =7.5 , xmax = 8.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  annotate("rect", xmin =9.5 , xmax = 10.5, ymin = -Inf, ymax = Inf, alpha = 0.1)+
  
  theme_bw()+
  
  theme(text = element_text(size = 10.5),
        strip.background = element_rect(size =0.6),
        
        panel.border = element_rect(size=0.6),
        
        axis.title.y = element_text(vjust=2.5,size=8.3),
        
        axis.text.x = element_text(size = 8.3, angle = 45, hjust = 1),
        axis.text.y = element_text(size = 8.3),
        
        #axis.line = element_line(size=0.35),
        
        axis.ticks.x = element_line(size = 0.6),
        axis.ticks.y = element_line(size = 0.6),
        
        panel.grid.major.y=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        panel.grid.minor.y=element_blank(),
        panel.grid.major.x=element_line(colour = "grey65",size=0.3,linetype="dotted"),
        
        legend.title = element_blank(),
        legend.text = element_text(size =8.5),
        legend.position="bottom",
        legend.key.size = unit(0.3, "cm"),
        legend.direction = "horizontal")

dev.off()

